@@ -1,5 +1,5 @@
 from unicodedata import name
-from IPython.display import display, Latex
+from IPython.display import display, Markdown
 import math
 
 def compareLists(should, given):
@@ -55,7 +55,7 @@ class RM:
             i.display()
 
         if (len(self.relations) + len(self.subsets) + len(self.intersections) == 0):
-            display(Latex("(empty Relation)"))
+            display(Markdown("(empty Relation)"))
 
 
     def get_scaled_score(self, rm, scores, max_points, debug=False):
@@ -195,14 +195,14 @@ class ProjectedRelation:
         self.relationName = relationName
         self.attributes = attributes
 
-    def getLatex(self):
-        return self.relationName.replace("_", "\\_") \
-            + "[\\text{" \
-            + ", ".join(self.attributes).replace("_", "\\_") \
-            + "}]"
+    def getMarkdown(self):
+        return self.relationName \
+            + "[" \
+            + ", ".join(self.attributes) \
+            + "]"
 
     def display(self):
-        display(Latex("$"+self.getLatex()+"$"))
+        display(Markdown(self.getMarkdown()))
 
     def compareTo(self, projectedRelation):
         if (self.relationName != projectedRelation.relationName):
@@ -220,17 +220,16 @@ class Relation:
         self.attributeList = attributeList
         self.primaryKeys = primaryKeys
 
-    def getLatex(self):
-        return self.name.replace("_", "\\_") \
-            + "(\\text{" \
-            + ", ".join(map(lambda x: "\\underline{" + x + "}", self.primaryKeys)).replace("_", "\\_") \
+    def getMarkdown(self):
+        return self.name \
+            + "(" \
+            + ", ".join(map(lambda x: "<u>" + x + "</u>", self.primaryKeys)) \
             + ("" if len(self.primaryKeys) == 0 or len(self.attributeList) == 0 else ", ") \
-            + "}\\text{" \
-            + ", ".join(self.attributeList).replace("_", "\\_") \
-            + "})"
+            + ", ".join(self.attributeList) \
+            + ")"
 
     def display(self):
-        display(Latex("$" + self.getLatex() + "$"))
+        display(Markdown(self.getMarkdown()))
 
     def compareTo(self, relation):
         if (self.name != relation.name):
@@ -244,16 +243,16 @@ class Subset:
     rhs = None  # Takes a projected relation
 
     def __init__(self, lhs, rhs):
-        if ((not isinstance(lhs, ProjectedRelation)) or (not isinstance(rhs, ProjectedRelation))):
-            print("Fehler: An ein Subset sollten zwei ProjectedRelations übergeben werden")
+        # if ((not isinstance(lhs, ProjectedRelation)) or (not isinstance(rhs, ProjectedRelation))):
+        #print("Fehler: An ein Subset sollten zwei ProjectedRelations übergeben werden")
         self.lhs = lhs
         self.rhs = rhs
 
-    def getLatex(self):
-        return self.lhs.getLatex() + "\\subseteq " + self.rhs.getLatex()
+    def getMarkdown(self):
+        return self.lhs.getMarkdown() + " ⊆ " + self.rhs.getMarkdown()
 
     def display(self):
-        display(Latex("$" + self.getLatex() + "$"))
+        display(Markdown(self.getMarkdown()))
 
     def compareTo(self, subset):
         return self.lhs.compareTo(subset.lhs) + self.rhs.compareTo(subset.rhs)
@@ -265,19 +264,18 @@ class Intersection:
     equals = ""
 
     def __init__(self, lhs, rhs, equals):
-        if ((not isinstance(lhs, ProjectedRelation)) or (not isinstance(rhs, ProjectedRelation))):
-            print("Fehler: An eine Intersection sollten zwei ProjectedRelations übergeben werden")
+        # if ((not isinstance(lhs, ProjectedRelation)) or (not isinstance(rhs, ProjectedRelation))):
+        #print("Fehler: An eine Intersection sollten zwei ProjectedRelations übergeben werden")
         self.lhs = lhs
         self.rhs = rhs
         self.equals = equals
 
-    def getLatex(self):
-        return self.lhs.getLatex() + "\\cap " + self.rhs.getLatex() + " = " + self.equals.replace("_", "\\_")
+    def getMarkdown(self):
+        return self.lhs.getMarkdown() + " ∩ " + self.rhs.getMarkdown() + " = " + self.equals
 
     def display(self):
-        display(Latex("$" + self.getLatex() + "$"))
+        display(Markdown(self.getMarkdown()))
 
     def compareTo(self, intersection):
-        if (self.equals != intersection.equals):
-            return 0
+        # self.equals will not be tested
         return self.rhs.compareTo(intersection.rhs) + self.lhs.compareTo(intersection.lhs)
